from __future__ import with_statement
import os.path

MODULE_TEMPLATE=""".. Autogenerated by genmods.py

******************************************************************************
%(name)s
******************************************************************************

:mod:`%(package)s.%(module)s`
==============================================================================

.. automodule:: %(package)s.%(module)s
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

"""

INDEX_TEMPLATE=""".. Autogenerated by genmods.py

.. _api-index:

##############################################################################
   %(package_name)s
##############################################################################

.. only:: html

   :Release: |version|
   :Date: |today|

.. toctree::

   %(rsts)s
"""


def genfiles(package, package_name, modules, dir='api'):

    if not os.path.exists(dir):
        os.makedirs(dir)

    for module,name in modules:
        with open(os.path.join(dir,module+'.rst'), 'w') as f:
            f.write(MODULE_TEMPLATE%locals())

    rsts = "\n   ".join(module+'.rst' for module,name in modules)
    with open(os.path.join(dir,'index.rst'),'w') as f:
        f.write(INDEX_TEMPLATE%locals())


modules=[
    ('BaseInteractor', 'BaseInteractor'),
    ('binder', 'binder'),
    ('canvas', 'canvas'),
    ('config', 'config'),
    ('fitDialog', 'fitDialog'),
    ('fittings', 'fittings'),
    ('LineModel', 'LineModel'),
    ('PlotPanel', 'PlotPanel'),
    ('plottable_interactor', 'plottable_interactor'),
    ('plottables', 'plottables'),
    ('PropertyDialog', 'PropertyDialog'),
    ('toolbar', 'toolbar'),
    ('transform', 'transform'),
    ('unitConverter', 'unitConverter'),
]
package = 'danse.common.plottools'
package_name = 'Reference'

if __name__ == "__main__":
    genfiles(package, package_name, modules, dir='../../../sphinx-docs/api/danse/common/plottools')
    print "Sphinx: generate .rst files complete..."
